==> 2.4.zip: piwigo/language/da_DK/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installation';
$lang['Basic configuration'] = 'Grundlæggende opsætning';
$lang['Default gallery language'] = 'Galleriets standardsprog';
$lang['Database configuration'] = 'Databaseopsætning';
$lang['Admin configuration'] = 'Admin-opsætning';
$lang['Start Install'] = 'Begynd installation';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'mailadresser skal være på formen xxx@yyy.eee (eksempel: jack@altern.org)';
$lang['Webmaster login'] = 'Webmasters login';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Det vil blive vist til de besøgende. Det er nødvendigt til administration af webstedet';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Forbindelsen til server er oprettet, men det var ikke muligt at få forbindelse til databasen';
$lang['Can\'t connect to server'] = 'Kan ikke få forbindelse til serveren';
$lang['Host'] = 'Host';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = 'Bruger';
$lang['user login given by your host provider'] = 'brugerlogin som du har fra din webhost';
$lang['Password'] = 'Adgangskode';
$lang['user password given by your host provider'] = 'brugeradgangskode som du har fra din webhost';
$lang['Database name'] = 'Databasenavn';
$lang['also given by your host provider'] = 'som du også har fået af din webhost';
$lang['Database table prefix'] = 'Tabelpræfiks i databasen';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'tabelnavne i databasen vil være fornynet med et præfiks (giver dig bedre mulighed for at administrere tabellerne)';
$lang['enter a login for webmaster'] = 'indtast webmasters login';
$lang['webmaster login can\'t contain characters \' or "'] = 'webmasterlogin må ikke indeholde tegnene \' eller "';
$lang['please enter your password again'] = 'indtast din adgangskode igen';
$lang['Webmaster password'] = 'Webmasters adgangskode';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hold det hemmeligt, det giver dig adgang til administrationspanelet.';
$lang['Password [confirm]'] = 'Password [bekræft]';
$lang['verification'] = 'bekræftelse';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Brug for hjælp? Stil dine spørgsmål i <a href="%s">Piwigos forum</a>.';
$lang['Webmaster mail address'] = 'Webmasters mailadresse';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besøgende vil ved hjælp af denne e-mail have mulighed for at kontakte administratoren';
$lang['PHP 5 is required'] = 'PHP 5 er nødvendig';
$lang['It appears your webhost is currently running PHP %s.'] = 'Det lader til, at din webhost pt. kører PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan prøve at skifte din opsætning til PHP 5 ved at oprette eller ændre en .htaccess-fil.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Bemærk, at du selv kan ændre din opsætning og derefter genstarte Piwigo.';
$lang['Try to configure PHP 5'] = 'Prøv at opsætte PHP 5';
$lang['Sorry!'] = 'Hov!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo var ikke i stand til at opsætte PHP 5.';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = "Du henvises til din webhost for at se hvordan du selv kan skifte til PHP 5.";
$lang['Hope to see you back soon.'] = 'Håber snart at se dig igen.';
$lang['Congratulations, Piwigo installation is completed'] = 'Tillykke, installeringen af Piwigo er afsluttet';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'En alternativ måde er at kopiere teksten i boksen oven over og sætte den ind i filen "local/config/database.inc.php" (Advarsel: database.inc.php må kun indeholde, hvad der er i tekstfeltet, ingen linjeskift eller mellemrum)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Oprettelsen af local/config/database.inc.php gik galt.';
$lang['Download the config file'] = 'Download opsætningsfilen';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan downloade opsætningsfilen og uploade den til mappen local/config i din installation.';
$lang['Just another Piwigo gallery'] = 'Bare endnu et Piwigo-galleri';
$lang['Welcome to my photo gallery'] = 'Velkommen til mit fotogalleri';

$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Tøv ikke med at besøges vores forum for at få hjælp: %s';
$lang['Welcome to your new installation of Piwigo!'] = 'Velkommen til din nye Piwigo-installation';
$lang['Password ']['confirm'] = 'Adgangskode [bekræft]';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Du henvises til din webhosts support for at finde ud af, om du selv kan skifte til PHP 5.';
?>

==> 14.5.0.zip: piwigo/language/da_DK/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = 'Installation';
$lang['Basic configuration'] = 'Grundlæggende opsætning';
$lang['Default gallery language'] = 'Galleriets standardsprog';
$lang['Database configuration'] = 'Databaseopsætning';
$lang['Admin configuration'] = 'Administrationsopsætning';
$lang['Start Install'] = 'Begynd installation';
$lang['It will be shown to the visitors. It is necessary for website administration'] = 'Det vil blive vist til de besøgende. Det er nødvendigt til administration af webstedet';
$lang['Connection to server succeed, but it was impossible to connect to database'] = 'Forbindelsen til server er oprettet, men det var ikke muligt at få forbindelse til databasen';
$lang['Can\'t connect to server'] = 'Kan ikke få forbindelse til serveren';
$lang['Host'] = 'Host';
$lang['User'] = 'Bruger';
$lang['user login given by your host provider'] = 'brugerlogin som du har fra din webhost';
$lang['user password given by your host provider'] = 'brugeradgangskode som du har fra din webhost';
$lang['Database name'] = 'Databasenavn';
$lang['also given by your host provider'] = 'som du også har fået af din webhost';
$lang['Database table prefix'] = 'Tabelpræfiks i databasen';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = 'tabelnavne i databasen vil være forsynet med et præfiks (giver dig bedre mulighed for at administrere tabellerne)';
$lang['enter a login for webmaster'] = 'indtast webmasters login';
$lang['webmaster login can\'t contain characters \' or "'] = 'webmasterlogin må ikke indeholde tegnene \' eller "';
$lang['please enter your password again'] = 'indtast din adgangskode igen';
$lang['Keep it confidential, it enables you to access administration panel'] = 'Hold det hemmeligt, det giver dig adgang til administrationspanelet.';
$lang['Password [confirm]'] = 'Password [bekræft]';
$lang['verification'] = 'bekræftelse';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = 'Brug for hjælp? Stil dine spørgsmål i <a href="%s">Piwigos forum</a>.';
$lang['Visitors will be able to contact site administrator with this mail'] = 'Besøgende vil ved hjælp af denne e-mail have mulighed for at kontakte administratoren';
$lang['PHP 5 is required'] = 'PHP 5.2 er nødvendig';
$lang['It appears your webhost is currently running PHP %s.'] = 'Det lader til, at din webhost pt. kører PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo kan prøve at skifte din opsætning til PHP 5.2 ved at oprette eller ændre en .htaccess-fil.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = 'Bemærk, at du selv kan ændre din opsætning og derefter genstarte Piwigo.';
$lang['Try to configure PHP 5'] = 'Prøv at opsætte PHP 5.2';
$lang['Sorry!'] = 'Hov!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo var ikke i stand til at opsætte PHP 5.2';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = "Du henvises til din webhost for at se hvordan du selv kan skifte til PHP 5.";
$lang['Hope to see you back soon.'] = 'Håber snart at se dig igen.';
$lang['Congratulations, Piwigo installation is completed'] = 'Tillykke, installeringen af Piwigo er afsluttet';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'En alternativ måde er at kopiere teksten i boksen oven over og sætte den ind i filen "local/config/database.inc.php" (Advarsel: database.inc.php må kun indeholde, hvad der er i tekstfeltet, ingen linjeskift eller mellemrum)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'Oprettelsen af local/config/database.inc.php gik galt.';
$lang['Download the config file'] = 'Download opsætningsfilen';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Du kan downloade opsætningsfilen og uploade den til mappen local/config i din installation.';
$lang['Just another Piwigo gallery'] = 'Bare endnu et Piwigo-galleri';
$lang['Welcome to my photo gallery'] = 'Velkommen til mit fotogalleri';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'Tøv ikke med at besøges vores forum for at få hjælp: %s';
$lang['Welcome to your new installation of Piwigo!'] = 'Velkommen til din nye Piwigo-installation';
$lang['Password ']['confirm'] = 'Adgangskode [bekræft]';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Du henvises til din webhosts support for at finde ud af, om du selv kan skifte til PHP 5.2';
$lang['localhost or other, supplied by your host provider'] = 'localhost eller andet, oplyst af din hostingleverandør';
$lang['PHP version %s required (you are running on PHP %s)'] = 'PHP version %s krævet (du kører PHP %s)';
